==> vod-api-model-1.0.0-sources.jar: com/valor/vod/api/model/meta/media/v1/MediaMetaDo.java <==
package com.valor.vod.api.model.meta.media.v1;


import java.util.ArrayList;
import java.util.List;

/**
 * Project     : volor
 * Description :
 * Author      : Frank
 * Create Time : 2016/1/24 16:34
 */
public class MediaMetaDo extends VideoMetaDO {
    private String firstAirDate;
    private String LastAirDate;
    private int numberOfEpisodes;
    private int numberOfSeasons;
    private String ended;
    private String type;
    private List<SeasonMetaDO> seasons = new ArrayList<>();

    private Long like = 0L;//hot点赞字段
    private Long unlike = 0L;//hot点踩字段
    private int likeStatus = 0;//0-normal,1-like,2-unlike

    public List<SeasonMetaDO> getSeasons() {
        return seasons;
    }

    public void setSeasons(List<SeasonMetaDO> seasons) {
        this.seasons = seasons;
    }

    public String getFirstAirDate() {
        return firstAirDate;
    }

    public void setFirstAirDate(String firstAirDate) {
        this.firstAirDate = firstAirDate;
    }

    public String getLastAirDate() {
        return LastAirDate;
    }

    public void setLastAirDate(String lastAirDate) {
        LastAirDate = lastAirDate;
    }

    public int getNumberOfEpisodes() {
        return numberOfEpisodes;
    }

    public void setNumberOfEpisodes(int numberOfEpisodes) {
        this.numberOfEpisodes = numberOfEpisodes;
    }

    public int getNumberOfSeasons() {
        return numberOfSeasons;
    }

    public void setNumberOfSeasons(int numberOfSeasons) {
        this.numberOfSeasons = numberOfSeasons;
    }

    public String getEnded() {
        return ended;
    }

    public void setEnded(String ended) {
        this.ended = ended;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getLike() {
        return like;
    }

    public void setLike(Long like) {
        this.like = like;
    }

    public Long getUnlike() {
        return unlike;
    }

    public void setUnlike(Long unlike) {
        this.unlike = unlike;
    }

    public int getLikeStatus() {
        return likeStatus;
    }

    public void setLikeStatus(int likeStatus) {
        this.likeStatus = likeStatus;
    }
}

==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/meta/media/v1/MediaMetaDo.java <==
package com.valor.vod.api.model.meta.media.v1;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Frank
 * @date 2016/1/24 16:34
 */
public class MediaMetaDo extends VideoMetaDO {
    private String firstAirDate;
    private int numberOfEpisodes;
    private int numberOfSeasons;
    private String ended;
    private String type;
    private List<SeasonMetaDO> seasons = new ArrayList<>();
    /** hot点赞字段 */
    private Long like = 0L;
    /** hot点踩字段 */
    private Long unlike = 0L;
    /** 0-normal,1-like,2-unlike */
    private int likeStatus = 0;

    public List<SeasonMetaDO> getSeasons() {
        return seasons;
    }

    public void setSeasons(List<SeasonMetaDO> seasons) {
        this.seasons = seasons;
    }

    public String getFirstAirDate() {
        return firstAirDate;
    }

    public void setFirstAirDate(String firstAirDate) {
        this.firstAirDate = firstAirDate;
    }

    public int getNumberOfEpisodes() {
        return numberOfEpisodes;
    }

    public void setNumberOfEpisodes(int numberOfEpisodes) {
        this.numberOfEpisodes = numberOfEpisodes;
    }

    public int getNumberOfSeasons() {
        return numberOfSeasons;
    }

    public void setNumberOfSeasons(int numberOfSeasons) {
        this.numberOfSeasons = numberOfSeasons;
    }

    public String getEnded() {
        return ended;
    }

    public void setEnded(String ended) {
        this.ended = ended;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Long getLike() {
        return like;
    }

    public void setLike(Long like) {
        this.like = like;
    }

    public Long getUnlike() {
        return unlike;
    }

    public void setUnlike(Long unlike) {
        this.unlike = unlike;
    }

    public int getLikeStatus() {
        return likeStatus;
    }

    public void setLikeStatus(int likeStatus) {
        this.likeStatus = likeStatus;
    }
}
